Description: Fix exception when old defaults are present.
 The value of the PlainTextEncoding key is NSString in versions prior
 to 5.0 which raises an exception when an -unsignedIntegerValue
 message is sent in -[DocumentController lastSelectedEncodingForURL:].
 This patch silently migrates the default to the new type, if it
 exists and its value is an NSString.
Author: Yavor Doganov <yavor@gnu.org>
Forwarded: Eric Wasylishen <ewasylishen@gmail.com>
Last-Update: 2018-02-12
---
 
--- textedit.app.orig/Controller.m
+++ textedit.app/Controller.m
@@ -108,8 +108,17 @@
 @implementation Controller
 
 + (void)initialize {
+    NSUserDefaults *d = [NSUserDefaults standardUserDefaults];
+
+    if ([d stringForKey:PlainTextEncodingForRead])
+        [d setObject:
+             [NSNumber numberWithUnsignedInteger:
+                                [[d stringForKey:PlainTextEncodingForRead]
+                                  integerValue]]
+              forKey:PlainTextEncodingForRead];
+
     // Set up default values for preferences managed by NSUserDefaultsController
-    [[NSUserDefaults standardUserDefaults] registerDefaults:defaultValues()];
+    [d registerDefaults:defaultValues()];
     [[NSUserDefaultsController sharedUserDefaultsController] setInitialValues:defaultValues()];
 }
 
